@@ -2,18 +2,6 @@
 
 require 'fileutils'
 
-class Object
-  def deprecated message:, date:
-    text = +''
-    text << "Deprecated(#{date}): "
-    text << message
-    caller(1..2).each do |line|
-      text << "\n-> Called from #{line}"
-    end
-    warn text
-  end
-end
-
 class Exporter
   attr_reader :project_configs
   attr_accessor :file_system
@@ -76,12 +64,8 @@ class Exporter
     selected = []
     each_project_config(name_filter: name_filter) do |project|
       project.evaluate_next_level
-      # next if project.aggregated_project?
 
       project.run load_only: true
-      project.board_configs.each do |board_config|
-        board_config.run
-      end
       project.issues.each do |issue|
         selected << [project, issue] if keys.include? issue.key
       end
@@ -91,9 +75,13 @@ class Exporter
       raise unless e.message.start_with? 'This is an aggregated project and issues should have been included'
     end
 
-    selected.each do |project, issue|
-      puts "\nProject #{project.name}"
-      puts issue.dump
+    if selected.empty?
+      file_system.log "No issues found to match #{keys.collect(&:inspect).join(', ')}"
+    else
+      selected.each do |project, issue|
+        file_system.log "\nProject #{project.name}", also_write_to_stderr: true
+        file_system.log issue.dump, also_write_to_stderr: true
+      end
     end
   end
 
@@ -128,7 +116,9 @@ class Exporter
 
   def jira_config filename = nil
     if filename
-      @jira_config = file_system.load_json(filename)
+      @jira_config = file_system.load_json(filename, fail_on_error: false)
+      raise "Unable to load Jira configuration file and cannot continue: #{filename.inspect}" if @jira_config.nil?
+
       @jira_config['url'] = $1 if @jira_config['url'] =~ /^(.+)\/+$/
     end
     @jira_config
